// index.js for simple-git-hooks-runner
import simpleGit from 'simple-git';
import cron from 'node-cron';
import dotenv from 'dotenv';

dotenv.config();

const runGitHooks = async (hookName, actions) => {
  const git = simpleGit();
  const hookActions = actions[hookName];

  if (hookActions && hookActions.length) {
    console.log(`Running actions for ${hookName} hook...`);
    for (const action of hookActions) {
      try {
        const result = await action(git);
        console.log(result);
      } catch (error) {
        console.error(`Error executing action for ${hookName}: ${error}`);
        process.exit(1);
      }
    }
  }
};

// Example usage
cron.schedule('* * * * *', () => { // This is just a placeholder for your actual scheduling needs
  runGitHooks('pre-commit', {
    'pre-commit': [
      async (git) => await git.add('.').commit('Auto-commit changes'),
    ],
  });
});

export default runGitHooks;

